==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/securityhub/kotlin/inputs/InsightFiltersResourceAwsEc2InstanceIpv4AddressArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.securityhub.kotlin.inputs

import com.pulumi.aws.securityhub.inputs.InsightFiltersResourceAwsEc2InstanceIpv4AddressArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property cidr A finding's CIDR value.
 */
public data class InsightFiltersResourceAwsEc2InstanceIpv4AddressArgs(
    public val cidr: Output<String>,
) :
    ConvertibleToJava<com.pulumi.aws.securityhub.inputs.InsightFiltersResourceAwsEc2InstanceIpv4AddressArgs> {
    override fun toJava():
        com.pulumi.aws.securityhub.inputs.InsightFiltersResourceAwsEc2InstanceIpv4AddressArgs =
        com.pulumi.aws.securityhub.inputs.InsightFiltersResourceAwsEc2InstanceIpv4AddressArgs.builder()
            .cidr(cidr.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [InsightFiltersResourceAwsEc2InstanceIpv4AddressArgs].
 */
@PulumiTagMarker
public class InsightFiltersResourceAwsEc2InstanceIpv4AddressArgsBuilder internal constructor() {
    private var cidr: Output<String>? = null

    /**
     * @param value A finding's CIDR value.
     */
    @JvmName("orrxbjgifqtqwuub")
    public suspend fun cidr(`value`: Output<String>) {
        this.cidr = value
    }

    /**
     * @param value A finding's CIDR value.
     */
    @JvmName("jwtbhgklmymnkofe")
    public suspend fun cidr(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.cidr = mapped
    }

    internal fun build(): InsightFiltersResourceAwsEc2InstanceIpv4AddressArgs =
        InsightFiltersResourceAwsEc2InstanceIpv4AddressArgs(
            cidr = cidr ?: throw PulumiNullFieldException("cidr"),
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/securityhub/kotlin/inputs/InsightFiltersResourceAwsEc2InstanceIpv4AddressArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.securityhub.kotlin.inputs

import com.pulumi.aws.securityhub.inputs.InsightFiltersResourceAwsEc2InstanceIpv4AddressArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property cidr A finding's CIDR value.
 */
public data class InsightFiltersResourceAwsEc2InstanceIpv4AddressArgs(
    public val cidr: Output<String>,
) :
    ConvertibleToJava<com.pulumi.aws.securityhub.inputs.InsightFiltersResourceAwsEc2InstanceIpv4AddressArgs> {
    override fun toJava(): com.pulumi.aws.securityhub.inputs.InsightFiltersResourceAwsEc2InstanceIpv4AddressArgs =
        com.pulumi.aws.securityhub.inputs.InsightFiltersResourceAwsEc2InstanceIpv4AddressArgs.builder()
            .cidr(cidr.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [InsightFiltersResourceAwsEc2InstanceIpv4AddressArgs].
 */
@PulumiTagMarker
public class InsightFiltersResourceAwsEc2InstanceIpv4AddressArgsBuilder internal constructor() {
    private var cidr: Output<String>? = null

    /**
     * @param value A finding's CIDR value.
     */
    @JvmName("cnibwjfkpisgomnj")
    public suspend fun cidr(`value`: Output<String>) {
        this.cidr = value
    }

    /**
     * @param value A finding's CIDR value.
     */
    @JvmName("lxesufdwpiawpdem")
    public suspend fun cidr(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.cidr = mapped
    }

    internal fun build(): InsightFiltersResourceAwsEc2InstanceIpv4AddressArgs =
        InsightFiltersResourceAwsEc2InstanceIpv4AddressArgs(
            cidr = cidr ?: throw PulumiNullFieldException("cidr"),
        )
}
